# WinTmp

This is a python module used to getting temperatures of the cpu and gpu in windows. If a hardware configurate does not work, make sure to open an issue. 

Remember run as admin!

Install:
`pip install WinTmp`

In admin command prompt type `python`.
Demo:

```python
>>> import WinTmp

>>> print(WinTmp.CPU_Temp())

>>> print(WinTmp.GPU_Temp())
```

PyPI page here: https://pypi.org/project/WinTmp/

Github Page Here: https://github.com/kethan1/WinTmp/
